==> kara-uc-1.1.16.tgz: package/src/kara-uc/components/UCFavorite/Colleague/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import DataUtil from '../../../util/dateTime'
import Scroll from 'react-scroller-plugin'
import ColleagueComponent from '../All/colleagueComponent/index'
import 'react-scroller-plugin/lib/scroll.css'
import tost from "kara-module-tost";
@inject('FavoriteStore','ConfigStore')

@observer
class KaraColleague extends Component{
  constructor(props) {
    super(props)
    this.state = {
      iconList: [],
      showAll: false
    }
  }
  onBottom = ()=> {
    let pn = this.props.FavoriteStore.topicList.pageNo + 1
    if(pn <= this.props.FavoriteStore.topicList.pageCount){
      this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/quan',{keywords: this.props.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.topicList.pageSiz,
          pageNo: pn
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getTopicList(res, pn)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  componentDidMount(){
    this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/quan',{keywords: this.props.keywords, 
      isShowRich: 'true', 
      pageInfo:{
        pageSize: this.props.FavoriteStore.topicList.pageSiz,
        pageNo: this.props.FavoriteStore.topicList.pageNo
      }
    }).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') { 
            this.props.FavoriteStore.getTopicList(res, this.props.FavoriteStore.topicList.pageNo)
        }
        else {
          tost({type:'error',msg:'列表信息加载失败',time:4}) 
        }
      }
    )
  }
  componentWillReceiveProps(nextProps) {
    if(this.props.keywords != nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/quan',{keywords: nextProps.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.topicList.pageSiz,
          pageNo: 1
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getTopicList(res, this.props.FavoriteStore.topicList.pageNo)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  render(){
    const {lang} = this.props
    const {topicList} = this.props.FavoriteStore
    return (
      <div className={css.KaraColleague}>
      <Scroll onScrollBottom={this.onBottom}>
      {topicList.result ? topicList.result.map((i,k)=> {
              return <ColleagueComponent key={k} fileAttr={i}  fromPage='colleague'  lang={lang}
                                         httpAgent={this.props.ConfigStore.config.httpAgent}
              apiForward= {this.props.ConfigStore.config.apiForward}
              cancelImFavorite={this.props.FavoriteStore.cancelImFavorite} 
              cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite} />
            }) : null}
            </Scroll>
      </div>
    )
  }
}

export default KaraColleague

==> kara-uc-1.1.29.tgz: package/src/kara-uc/components/UCFavorite/Colleague/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import ColleagueComponent from '../All/colleagueComponent/index'
import tost from "kara-module-tost";
@inject('FavoriteStore','ConfigStore')

@observer
class KaraColleague extends Component{
  constructor(props) {
    super(props)
    this.state = {
      iconList: [],
      showAll: false
    }
  }
  onBottom = ()=> {
    let pn = this.props.FavoriteStore.topicList.pageNo + 1
    if(pn <= this.props.FavoriteStore.topicList.pageCount){
      this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/quan',{keywords: this.props.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.topicList.pageSiz,
          pageNo: pn
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getTopicList(res, pn)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  componentDidMount(){
    this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/quan',{keywords: this.props.keywords, 
      isShowRich: 'true', 
      pageInfo:{
        pageSize: this.props.FavoriteStore.topicList.pageSiz,
        pageNo: this.props.FavoriteStore.topicList.pageNo
      }
    }).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') { 
            this.props.FavoriteStore.getTopicList(res, this.props.FavoriteStore.topicList.pageNo)
        }
        else {
          tost({type:'error',msg:'列表信息加载失败',time:4}) 
        }
      }
    )
  }
  componentWillReceiveProps(nextProps) {
    if(this.props.keywords != nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/imsv/search/mine/favorite/quan',{keywords: nextProps.keywords, 
        isShowRich: 'true', 
        pageInfo:{
          pageSize: this.props.FavoriteStore.topicList.pageSiz,
          pageNo: 1
        }
      }).then(
        res => {
          if(res && res.resultCode && res.resultCode === '000000') { 
              this.props.FavoriteStore.getTopicList(res, this.props.FavoriteStore.topicList.pageNo)
          }
          else {
            tost({type:'error',msg:'列表信息加载失败',time:4}) 
          }
        }
      )
    }
  }
  render(){
    const {ConfigStore,FavoriteStore,lang} = this.props
    const {karaui, httpAgent} = ConfigStore.config
    const {topicList} = FavoriteStore
    const { Scroll } = karaui
    return (
      <div className={css.KaraColleague}>
      <Scroll onScrollBottom={this.onBottom}>
      {topicList.result ? topicList.result.map((i,k)=> {
              return <ColleagueComponent
                key={k}
                fileAttr={i}
                fromPage='colleague'
                lang={lang}
                karaui={karaui}
                httpAgent={httpAgent}
                apiForward= {this.props.ConfigStore.config.apiForward}
                cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
                cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite} />
            }) : null}
            </Scroll>
      </div>
    )
  }
}

export default KaraColleague
